@@ -1,10 +1,9 @@
 
-#include "kmime_headers.h"
-#include "kmime_header_parsing.h"
+#include "headers.h"
+#include "headerparsing.h"
 
 #include <QFile>
 #include <QByteArray>
-#include <QMap>
 #include <iostream>
 #include <cstdlib>
 #include <cassert>
@@ -31,7 +30,6 @@ static const char *tokenTypes[] = {
     "group",
     "address",
     "address-list",
-    "parameter-list",
     "time",
     "date-time"
 };
@@ -159,7 +157,7 @@ int main(int argc, char *argv[])
     case 1: {
         // atom
         cout << "with 8bit: " << endl;
-        QByteArray result;
+        QByteArrayView result;
         bool ok = parseAtom(iit, iend, result, true);
 
         cout << (ok ? "OK" : "BAD") << endl
@@ -179,29 +177,6 @@ int main(int argc, char *argv[])
              << endl;
     }
     break;
-    case 2: {
-        // token
-        cout << "with 8bit: " << endl;
-        QByteArray result;
-        bool ok = parseToken(iit, iend, result, ParseTokenAllow8Bit);
-
-        cout << (ok ? "OK" : "BAD") << endl
-             << "result:\n" << result.constData()
-             << endl;
-
-        cout << "without 8bit: " << endl;
-#ifdef COMPILE_FAIL
-        ok = parseToken(indata.begin(), iend, result, ParseTokenNoFlag);
-#else
-        iit = indata.begin();
-        ok = parseToken(iit, iend, result, ParseTokenNoFlag);
-#endif
-
-        cout << (ok ? "OK" : "BAD") << endl
-             << "result:\n" << result.constData()
-             << endl;
-    }
-    break;
     case 3: {
         // quoted-string
         QString result;
@@ -386,25 +361,6 @@ int main(int argc, char *argv[])
     }
     break;
     case 16: {
-        // parameter-list
-        QMap<QString, QString> result;
-        bool ok = parseParameterList(iit, iend, result, withCRLF);
-
-        cout << (ok ? "OK" : "BAD") << endl
-             << "result: " << result.count() << " parameters:"
-             << endl;
-        int i = 0;
-        for (QMap<QString, QString>::Iterator it = result.begin() ;
-                it != result.end() ; ++it, ++i) {
-            cout << "result[" << i << "].key() (attribute):\n"
-                 << it.key() << endl
-                 << "result[" << i << "].data() (value):\n"
-                 << it.value()
-                 << endl;
-        }
-    }
-    break;
-    case 17: {
         // time
         int hour;
         int mins;
@@ -424,7 +380,7 @@ int main(int argc, char *argv[])
              << endl;
     }
     break;
-    case 18: {
+    case 17: {
         // date-time
         QDateTime result;
         bool ok =  parseDateTime(iit, iend, result, withCRLF);
